==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/eu.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Egutegi guztiak ez daude guztiz cacheatuta",
"Everything seems to be completely cached" => "Dena guztiz cacheatuta dagoela dirudi",
"No calendars found." => "Ez da egutegirik aurkitu.",
"No events found." => "Ez da gertaerarik aurkitu.",
"Wrong calendar" => "Egutegi okerra",
"You do not have the permissions to edit this event." => "Gertaera hau editatzeko baimenik ez daukazu.",
"The file contained either no events or all events are already saved in your calendar." => "Fitxategiak ez zuen gertaerarik edo gertaera guztiak dagoeneko egutegian gordeta zeuden.",
"events has been saved in the new calendar" => "gertaerak egutegi berrian gorde dira",
"Import failed" => "Inportazioak huts egin du",
"events has been saved in your calendar" => "gertaerak zure egutegian gorde dira",
"New Timezone:" => "Ordu-zonalde berria",
"Timezone changed" => "Ordu-zonaldea aldatuta",
"Invalid request" => "Baliogabeko eskaera",
"Calendar" => "Egutegia",
"Deletion failed" => "Ezabaketak huts egin du",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "[ yyyy]  MMMM ddd d{ - yyyy MMMM [ddd d] }",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "[ yyyy]  MMMM ddd d HH:mm{ - yyyy MMMM [ddd d] HH:mm}",
"user" => "erabiltzailea",
"group" => "taldea",
"Editable" => "Editagarria",
"Shareable" => "Partekagarria",
"Deletable" => "Ezabagarria",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "yyyy MMMM",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "[ yyyy] MMM d{ '&#8212;'yyyy [ MMM] d}",
"dddd, MMM d, yyyy" => "yyyy, MMM d, dddd",
"Sunday" => "Igandea",
"Monday" => "Astelehena",
"Tuesday" => "Asteartea",
"Wednesday" => "Asteazkena",
"Thursday" => "Osteguna",
"Friday" => "Ostirala",
"Saturday" => "Larunbata",
"Sun." => "ig.",
"Mon." => "al.",
"Tue." => "ar.",
"Wed." => "az.",
"Thu." => "og.",
"Fri." => "ol.",
"Sat." => "lr.",
"January" => "Urtarrila",
"February" => "Otsaila",
"March" => "Martxoa",
"April" => "Apirila",
"May" => "Maiatza",
"June" => "Ekaina",
"July" => "Uztaila",
"August" => "Abuztua",
"September" => "Iraila",
"October" => "Urria",
"November" => "Azaroa",
"December" => "Abendua",
"Jan." => "urt.",
"Feb." => "ots.",
"Mar." => "mar.",
"Apr." => "api.",
"May." => "mai.",
"Jun." => "eka.",
"Jul." => "uzt.",
"Aug." => "abu.",
"Sep." => "ira.",
"Oct." => "urr.",
"Nov." => "aza.",
"Dec." => "abe.",
"All day" => "Egun guztia",
"New Calendar" => "Egutegi berria",
"Missing or invalid fields" => "Eremuak falta dira edo gaizki daude",
"Title" => "Izenburua",
"From Date" => "Hasierako Data",
"From Time" => "Hasierako Ordua",
"To Date" => "Bukaerako Data",
"To Time" => "Bukaerako Ordua",
"The event ends before it starts" => "Gertaera hasi baino lehen bukatzen da",
"There was a database fail" => "Datu-baseak huts egin du",
"Birthday" => "Jaioteguna",
"Business" => "Negozioa",
"Call" => "Deia",
"Clients" => "Bezeroak",
"Deliverer" => "Banatzailea",
"Holidays" => "Oporrak",
"Ideas" => "Ideiak",
"Journey" => "Bidaia",
"Jubilee" => "Urteurrena",
"Meeting" => "Bilera",
"Other" => "Bestelakoa",
"Personal" => "Pertsonala",
"Projects" => "Proiektuak",
"Questions" => "Galderak",
"Work" => "Lana",
"unnamed" => "izengabea",
"You do not have the permissions to update this calendar." => "Egutegi hau eguneratzeko baimenik ez daukazu.",
"You do not have the permissions to delete this calendar." => "Egutegi hau ezabatzeko baimenik ez daukazu.",
"You do not have the permissions to add to this calendar." => "Egutegi honetan gehitzeko baimenik ez daukazu.",
"You do not have the permissions to add events to this calendar." => "Egutegi honetan gertaerak gehitzeko baimenik ez daukazu.",
"You do not have the permissions to delete this event." => "Gertaera hau ezabatzeko baimenik ez daukazu.",
"Busy" => "Lanpetuta",
"Public" => "Publikoa",
"Private" => "Pribatua",
"Confidential" => "Konfidentziala",
"Does not repeat" => "Ez da errepikatzen",
"Daily" => "Egunero",
"Weekly" => "Astero",
"Every Weekday" => "Asteko egun guztietan",
"Bi-Weekly" => "Bi-Astero",
"Monthly" => "Hilabetero",
"Yearly" => "Urtero",
"never" => "inoiz",
"by occurrences" => "errepikapen kopuruagatik",
"by date" => "dataren arabera",
"by monthday" => "hileko egunaren arabera",
"by weekday" => "asteko egunaren arabera",
"events week of month" => "gertaeraren hilabeteko astea",
"first" => "lehenengoa",
"second" => "bigarrean",
"third" => "hirugarrena",
"fourth" => "laugarrena",
"fifth" => "bostgarrena",
"last" => "azkena",
"by events date" => "gertaeren dataren arabera",
"by yearday(s)" => "urteko egunaren arabera",
"by weeknumber(s)" => "aste zenbaki(ar)en arabera",
"by day and month" => "eguna eta hilabetearen arabera",
"Date" => "Data",
"Cal." => "Eg.",
"Week" => "Astea",
"Month" => "Hilabetea",
"List" => "Zerrenda",
"Today" => "Gaur",
"Settings" => "Ezarpenak",
"Your calendars" => "Zure egutegiak",
"CalDav Link" => "CalDav lotura",
"Share Calendar" => "Elkarbanatu egutegia",
"Download" => "Deskargatu",
"Edit" => "Editatu",
"Delete" => "Ezabatu",
"New calendar" => "Egutegi berria",
"Edit calendar" => "Editatu egutegia",
"Displayname" => "Bistaratzeko izena",
"Active" => "Aktiboa",
"Calendar color" => "Egutegiaren kolorea",
"Save" => "Gorde",
"Submit" => "Bidali",
"Cancel" => "Ezeztatu",
"Edit an event" => "Editatu gertaera",
"Export" => "Exportatu",
"Eventinfo" => "Gertaeraren informazioa",
"Repeating" => "Errepikapena",
"Alarm" => "Alarma",
"Attendees" => "Partaideak",
"Share" => "Elkarbanatu",
"Title of the Event" => "Gertaeraren izenburua",
"Category" => "Kategoria",
"Separate categories with commas" => "Banatu kategoriak komekin",
"Edit categories" => "Editatu kategoriak",
"Access Class" => "Sarrera mota",
"All Day Event" => "Egun osoko gertaera",
"From" => "Hasiera",
"To" => "Bukaera",
"Advanced options" => "Aukera aurreratuak",
"Location" => "Kokalekua",
"Location of the Event" => "Gertaeraren kokalekua",
"Description" => "Deskribapena",
"Description of the Event" => "Gertaeraren deskribapena",
"Repeat" => "Errepikatu",
"Advanced" => "Aurreratua",
"Select weekdays" => "Hautatu asteko egunak",
"Select days" => "Hautatu egunak",
"and the events day of year." => "eta gertaeraren urteko eguna.",
"and the events day of month." => "eta gertaeraren hilabeteko eguna.",
"Select months" => "Hautatu hilabeteak",
"Select weeks" => "Hautatu asteak",
"and the events week of year." => "eta gertaeraren urteko astea.",
"Interval" => "Tartea",
"End" => "Amaiera",
"occurrences" => "errepikapenak",
"create a new calendar" => "sortu egutegi berria",
"Import a calendar file" => "Inportatu egutegi fitxategi bat",
"Please choose a calendar" => "Mesedez aukeratu egutegi bat.",
"Name of new calendar" => "Egutegi berriaren izena",
"Take an available name!" => "Hartu eskuragarri dagoen izen bat!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Izen hau duen egutegi bat dagoeneko existitzen da. Hala ere jarraitzen baduzu, egutegi hauek elkartuko dira.",
"Remove all events from the selected calendar" => "Ezabatu hautatutako egutegiko gertaera guztiak",
"Import" => "Importatu",
"Close Dialog" => "Itxi lehioa",
"Create a new event" => "Sortu gertaera berria",
"Share with:" => "elkarbanatu honekin:",
"Shared with" => "Hauekin elkarbanatuta:",
"Unshare" => "Ez elkarbanatu",
"Nobody" => "Inor",
"Shared via calendar" => "Egutegiaren bidez elkarbanatuta",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "OHARRA: Egutegiaren bidez elkarbanatutako gertaeren gaineko ekintzak egutegi osoaren elkarbanatzean izango dute eragina.",
"View an event" => "Ikusi gertaera bat",
"No categories selected" => "Ez da kategoriarik hautatu",
"at" => "ordua",
"General" => "Orokorra",
"Timezone" => "Ordu-zonaldea",
"Update timezone automatically" => "Eguneratu ordu-zonaldea automatikoki",
"Time format" => "Ordu formatua",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Astea hasteko eguna",
"Cache" => "Cache",
"Clear cache for repeating events" => "Ezabatu gertaera errepikakorren cachea",
"URLs" => "URLak",
"Calendar CalDAV syncing addresses" => "Egutegiaren CalDAV sinkronizazio helbideak",
"more info" => "informazio gehiago",
"Primary address (Kontact et al)" => "Helbide nagusia",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Bakarrik irakurtzeko iCalendar lotura(k)"
);

==> owncloud-7.0.4.tgz: owncloud/apps/calendar/l10n/eu.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Egutegi guztiak ez daude guztiz cacheatuta",
"Everything seems to be completely cached" => "Dena guztiz cacheatuta dagoela dirudi",
"No calendars found." => "Ez da egutegirik aurkitu.",
"No events found." => "Ez da gertaerarik aurkitu.",
"Wrong calendar" => "Egutegi okerra",
"You do not have the permissions to edit this event." => "Gertaera hau editatzeko baimenik ez daukazu.",
"The file contained either no events or all events are already saved in your calendar." => "Fitxategiak ez zuen gertaerarik edo gertaera guztiak dagoeneko egutegian gordeta zeuden.",
"Import failed" => "Inportazioak huts egin du",
"New Timezone:" => "Ordu-zonalde berria",
"Timezone changed" => "Ordu-zonaldea aldatuta",
"Invalid request" => "Baliogabeko eskaera",
"Calendar" => "Egutegia",
"Deletion failed" => "Ezabaketak huts egin du",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "[ yyyy]  MMMM ddd d{ - yyyy MMMM [ddd d] }",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "[ yyyy]  MMMM ddd d HH:mm{ - yyyy MMMM [ddd d] HH:mm}",
"group" => "taldea",
"can edit" => "editatu dezake",
"can share" => "elkarbana dezake",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "yyyy MMMM",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "yyyy, MMM d, dddd",
"Sunday" => "Igandea",
"Monday" => "Astelehena",
"Tuesday" => "Asteartea",
"Wednesday" => "Asteazkena",
"Thursday" => "Osteguna",
"Friday" => "Ostirala",
"Saturday" => "Larunbata",
"Sun." => "ig.",
"Mon." => "al.",
"Tue." => "ar.",
"Wed." => "az.",
"Thu." => "og.",
"Fri." => "ol.",
"Sat." => "lr.",
"January" => "Urtarrila",
"February" => "Otsaila",
"March" => "Martxoa",
"April" => "Apirila",
"May" => "Maiatza",
"June" => "Ekaina",
"July" => "Uztaila",
"August" => "Abuztua",
"September" => "Iraila",
"October" => "Urria",
"November" => "Azaroa",
"December" => "Abendua",
"Jan." => "urt.",
"Feb." => "ots.",
"Mar." => "mar.",
"Apr." => "api.",
"May." => "mai.",
"Jun." => "eka.",
"Jul." => "uzt.",
"Aug." => "abu.",
"Sep." => "ira.",
"Oct." => "urr.",
"Nov." => "aza.",
"Dec." => "abe.",
"All day" => "Egun guztia",
"New Calendar" => "Egutegi berria",
"Missing or invalid fields" => "Eremuak falta dira edo gaizki daude",
"Title" => "Izenburua",
"From Date" => "Hasierako Data",
"From Time" => "Hasierako Ordua",
"To Date" => "Bukaerako Data",
"To Time" => "Bukaerako Ordua",
"The event ends before it starts" => "Gertaera hasi baino lehen bukatzen da",
"There was a database fail" => "Datu-baseak huts egin du",
"Interval is not valid. It must be a positive integer!" => "Tartea ez da egokia. Zenbaki oso positiboa izan behar du!",
"Birthday" => "Jaioteguna",
"Business" => "Negozioa",
"Call" => "Deia",
"Clients" => "Bezeroak",
"Deliverer" => "Banatzailea",
"Holidays" => "Oporrak",
"Ideas" => "Ideiak",
"Journey" => "Bidaia",
"Jubilee" => "Urteurrena",
"Meeting" => "Bilera",
"Other" => "Bestelakoa",
"Personal" => "Pertsonala",
"Projects" => "Proiektuak",
"Questions" => "Galderak",
"Work" => "Lana",
"by" => " Egilea:",
"unnamed" => "izengabea",
"You do not have the permissions to update this calendar." => "Egutegi hau eguneratzeko baimenik ez daukazu.",
"You do not have the permissions to delete this calendar." => "Egutegi hau ezabatzeko baimenik ez daukazu.",
"You do not have the permissions to add to this calendar." => "Egutegi honetan gehitzeko baimenik ez daukazu.",
"You do not have the permissions to add events to this calendar." => "Egutegi honetan gertaerak gehitzeko baimenik ez daukazu.",
"You cannot add non-public events to a shared calendar." => "Ezin duzu partekatutako egutegi batean publikoak ez diren gertaerak gehitu.",
"You do not have the permissions to delete this event." => "Gertaera hau ezabatzeko baimenik ez daukazu.",
"Busy" => "Lanpetuta",
"Show full event" => "Bistaratu gertaera osoa",
"Show only busy" => "Erakutsi bakarrik lanpetuta",
"Hide event" => "Ezkutatu gertaera",
"Does not repeat" => "Ez da errepikatzen",
"Daily" => "Egunero",
"Weekly" => "Astero",
"Every Weekday" => "Asteko egun guztietan",
"Bi-Weekly" => "Bi-Astero",
"Monthly" => "Hilabetero",
"Yearly" => "Urtero",
"never" => "inoiz",
"by occurrences" => "errepikapen kopuruagatik",
"by date" => "dataren arabera",
"by monthday" => "hileko egunaren arabera",
"by weekday" => "asteko egunaren arabera",
"events week of month" => "gertaeraren hilabeteko astea",
"first" => "lehenengoa",
"second" => "bigarrean",
"third" => "hirugarrena",
"fourth" => "laugarrena",
"fifth" => "bostgarrena",
"last" => "azkena",
"by events date" => "gertaeren dataren arabera",
"by yearday(s)" => "urteko egunaren arabera",
"by weeknumber(s)" => "aste zenbaki(ar)en arabera",
"by day and month" => "eguna eta hilabetearen arabera",
"Contact birthdays" => "kontaktuen urtebetetze datak",
"Date" => "Data",
"Cal." => "Eg.",
"Day" => "Eguna",
"Week" => "Astea",
"Month" => "Hilabetea",
"Today" => "Gaur",
"CalDav Link" => "CalDav lotura",
"Timezone" => "Ordu-zonaldea",
"Update timezone automatically" => "Eguneratu ordu-zonaldea automatikoki",
"Time format" => "Ordu formatua",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Astea hasteko eguna",
"Cache" => "Cache",
"Clear cache for repeating events" => "Ezabatu gertaera errepikakorren cachea",
"Primary CalDAV address" => "CalDAV helbide nagusia",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV helbidea",
"Share Calendar" => "Elkarbanatu egutegia",
"Download" => "Deskargatu",
"Edit" => "Editatu",
"Delete" => "Ezabatu",
"New calendar" => "Egutegi berria",
"Edit calendar" => "Editatu egutegia",
"Edit event" => "Editatu gertaera",
"Save event" => "Gorde gertaera",
"Delete event" => "Ezabatu gertaera",
"Eventinfo" => "Gertaeraren informazioa",
"Repeating" => "Errepikapena",
"Alarm" => "Alarma",
"Attendees" => "Partaideak",
"Share" => "Elkarbanatu",
"Title of the Event" => "Gertaeraren izenburua",
"from" => "lekua",
"to" => "Noiz arte",
"All Day Event" => "Egun osoko gertaera",
"Advanced options" => "Aukera aurreratuak",
"Location" => "Kokalekua",
"Categories (separate by comma)" => "Kategoriak (komaz banatuta)",
"Edit categories" => "Editatu kategoriak",
"Description" => "Deskribapena",
"Export event" => "Esportatu gertaera",
"Repeat" => "Errepikatu",
"Advanced" => "Aurreratua",
"Select weekdays" => "Hautatu asteko egunak",
"Select days" => "Hautatu egunak",
"and the events day of year." => "eta gertaeraren urteko eguna.",
"and the events day of month." => "eta gertaeraren hilabeteko eguna.",
"Select months" => "Hautatu hilabeteak",
"Select weeks" => "Hautatu asteak",
"and the events week of year." => "eta gertaeraren urteko astea.",
"Interval" => "Tartea",
"End" => "Amaiera",
"occurrences" => "errepikapenak",
"Visibility to people shared with" => "Bistaratzea elkarbanatutako pertsonekin",
"create a new calendar" => "sortu egutegi berria",
"Import a calendar file" => "Inportatu egutegi fitxategi bat",
"Please choose a calendar" => "Mesedez aukeratu egutegi bat.",
"Name of new calendar" => "Egutegi berriaren izena",
"Take an available name!" => "Hartu eskuragarri dagoen izen bat!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Izen hau duen egutegi bat dagoeneko existitzen da. Hala ere jarraitzen baduzu, egutegi hauek elkartuko dira.",
"Remove all events from the selected calendar" => "Ezabatu hautatutako egutegiko gertaera guztiak",
"Import" => "Importatu",
"Close Dialog" => "Itxi lehioa",
"Create a new event" => "Sortu gertaera berria",
"Create event" => "Sortu gertaera",
"Share with user or group" => "Elkarbanatu erabiltzaile edo taldearekin",
"Unshare" => "Ez elkarbanatu",
"Not shared with anyone" => "Ez dago elkarbanatuta",
"Send Email" => "Emaila bidali",
"Shared via calendar" => "Egutegiaren bidez elkarbanatuta",
"Not shared with anyone via calendar" => "Ez dago egutegiaren bidez partekatuta",
"View an event" => "Ikusi gertaera bat",
"Category" => "Kategoria",
"No categories selected" => "Ez da kategoriarik hautatu",
"%s of %s" => "%s / %s",
"Access Class" => "Sarrera mota",
"From" => "Hasiera",
"at" => "ordua",
"To" => "Bukaera"
);
